from smart_module.module_system.header_common import *
from smart_module.module_system.header_parties import *
from smart_module.module_system.ID_troops import *
from smart_module.module_system.ID_factions import *
from smart_module.module_system.ID_map_icons import *

pmf_is_prisoner = 0x0001

####################################################################################################################
#  Each party template record contains the following fields:
#  1) Party-template id: used for referencing party-templates in other files.
#     The prefix pt_ is automatically added before each party-template id.
#  2) Party-template name.
#  3) Party flags. See header_parties.py for a list of available flags
#  4) Menu. ID of the menu to use when this party is met. The value 0 uses the default party encounter system.
#  5) Faction
#  6) Personality. See header_parties.py for an explanation of personality flags.
#  7) List of stacks. Each stack record is a tuple that contains the following fields:
#    7.1) Troop-id. 
#    7.2) Minimum number of troops in the stack. 
#    7.3) Maximum number of troops in the stack. 
#    7.4) Member flags(optional). Use pmf_is_prisoner to note that this member is a prisoner.
#     Note: There can be at most 6 stacks.
####################################################################################################################


party_templates = [
  ("none","none",icon_gray_knight,0,fac_commoners,merchant_personality,[]),
  ("rescued_prisoners","Rescued Prisoners",icon_gray_knight,0,fac_commoners,merchant_personality,[]),
  ("enemy","Enemy",icon_gray_knight,0,fac_undeads,merchant_personality,[]),
  ("hero_party","Hero Party",icon_gray_knight,0,fac_commoners,merchant_personality,[]),
####################################################################################################################
# Party templates before this point are hard-wired into the game and should not be changed. 
####################################################################################################################
##  ("old_garrison","Old Garrison",icon_vaegir_knight,0,fac_neutral,merchant_personality,[]),
  ("village_defenders","Village Defenders",icon_peasant,0,fac_commoners,merchant_personality,[(trp_farmer,10,20),(trp_peasant_woman,0,4)]),

  ("cattle_herd","Cattle Herd",icon_cattle|carries_goods(10),0,fac_neutral,merchant_personality,[(trp_cattle,80,120)]),

##  ("vaegir_nobleman","Vaegir Nobleman",icon_vaegir_knight|carries_goods(10)|pf_quest_party,0,fac_commoners,merchant_personality,[(trp_nobleman,1,1),(trp_vaegir_knight,2,6),(trp_vaegir_horseman,4,12)]),
##  ("swadian_nobleman","Swadian Nobleman",icon_gray_knight|carries_goods(10)|pf_quest_party,0,fac_commoners,merchant_personality,[(trp_nobleman,1,1),(trp_swadian_knight,2,6),(trp_swadian_man_at_arms,4,12)]),
# Ryan BEGIN
  ("looters","Looters",icon_axeman|carries_goods(8),0,fac_outlaws,bandit_personality,[(trp_looter,3,45)]),
# Ryan END
  ("manhunters","Manhunters",icon_gray_knight,0,fac_manhunters,soldier_personality,[(trp_manhunter,9,40)]),
##  ("peasant","Peasant",icon_peasant,0,fac_commoners,merchant_personality,[(trp_farmer,1,6),(trp_peasant_woman,0,7)]),

#  ("black_khergit_raiders","Black Khergit Raiders",icon_khergit_horseman_b|carries_goods(2),0,fac_black_khergits,bandit_personality,[(trp_black_khergit_guard,1,10),(trp_black_khergit_horseman,5,5)]),
  ("steppe_bandits","Steppe Bandits",icon_khergit|carries_goods(2),0,fac_outlaws,bandit_personality,[(trp_steppe_bandit,4,58)]),
  ("taiga_bandits","Tundra Bandits",icon_axeman|carries_goods(2),0,fac_outlaws,bandit_personality,[(trp_taiga_bandit,4,58)]),
  ("desert_bandits","Desert Bandits",icon_vaegir_knight|carries_goods(2),0,fac_outlaws,bandit_personality,[(trp_desert_bandit,4,58)]),
  ("forest_bandits","Forest Bandits",icon_axeman|carries_goods(2),0,fac_forest_bandits,bandit_personality,[(trp_forest_bandit,4,52)]),
  ("mountain_bandits","Mountain Bandits",icon_axeman|carries_goods(2),0,fac_mountain_bandits,bandit_personality,[(trp_mountain_bandit,4,60)]),
  ("sea_raiders","Sea Raiders",icon_axeman|carries_goods(2),0,fac_outlaws,bandit_personality,[(trp_sea_raider,5,50)]),

  ("deserters","Deserters",icon_vaegir_knight|carries_goods(3),0,fac_deserters,bandit_personality,[]),
    
  ("merchant_caravan","Merchant Caravan",icon_gray_knight|carries_goods(20)|pf_auto_remove_in_town|pf_quest_party,0,fac_commoners,escorted_merchant_personality,[(trp_caravan_master,1,1),(trp_caravan_guard,5,25)]),
  ("troublesome_bandits","Troublesome Bandits",icon_axeman|carries_goods(9)|pf_quest_party,0,fac_outlaws,bandit_personality,[(trp_bandit,14,55)]),
  ("bandits_awaiting_ransom","Bandits Awaiting Ransom",icon_axeman|carries_goods(9)|pf_auto_remove_in_town|pf_quest_party,0,fac_neutral,bandit_personality,[(trp_bandit,24,58),(trp_kidnapped_girl,1,1,pmf_is_prisoner)]),
  ("kidnapped_girl","Kidnapped Girl",icon_woman|pf_quest_party,0,fac_neutral,merchant_personality,[(trp_kidnapped_girl,1,1)]),

  ("village_farmers","Village Farmers",icon_peasant|pf_civilian,0,fac_innocents,merchant_personality,[(trp_farmer,5,10),(trp_peasant_woman,3,8)]),

  ("spy_partners", "Unremarkable Travellers", icon_gray_knight|carries_goods(10)|pf_default_behavior|pf_quest_party,0,fac_neutral,merchant_personality,[(trp_spy_partner,1,1),(trp_caravan_guard,5,11)]),
  ("runaway_serfs","Runaway Serfs",icon_peasant|carries_goods(8)|pf_default_behavior|pf_quest_party,0,fac_neutral,merchant_personality,[(trp_farmer,6,7), (trp_peasant_woman,3,3)]),
  ("spy", "Ordinary Townsman", icon_gray_knight|carries_goods(4)|pf_default_behavior|pf_quest_party,0,fac_neutral,merchant_personality,[(trp_spy,1,1)]),
  ("sacrificed_messenger", "Sacrificed Messenger", icon_gray_knight|carries_goods(3)|pf_default_behavior|pf_quest_party,0,fac_neutral,merchant_personality,[]),
##  ("conspirator", "Conspirators", icon_gray_knight|carries_goods(8)|pf_default_behavior|pf_quest_party,0,fac_neutral,merchant_personality,[(trp_conspirator,3,4)]),
##  ("conspirator_leader", "Conspirator Leader", icon_gray_knight|carries_goods(8)|pf_default_behavior|pf_quest_party,0,fac_neutral,merchant_personality,[(trp_conspirator_leader,1,1)]),
##  ("peasant_rebels", "Peasant Rebels", icon_peasant,0,fac_peasant_rebels,bandit_personality,[(trp_peasant_rebel,33,97)]),
##  ("noble_refugees", "Noble Refugees", icon_gray_knight|carries_goods(12)|pf_quest_party,0,fac_noble_refugees,merchant_personality,[(trp_noble_refugee,3,5),(trp_noble_refugee_woman,5,7)]),

  ("forager_party","Foraging Party",icon_gray_knight|carries_goods(5)|pf_show_faction,0,fac_commoners,merchant_personality,[]),
  ("scout_party","Scouts",icon_gray_knight|carries_goods(1)|pf_show_faction,0,fac_commoners,bandit_personality,[]),
  ("patrol_party","Patrol",icon_gray_knight|carries_goods(2)|pf_show_faction,0,fac_commoners,soldier_personality,[]),
#  ("war_party", "War Party",icon_gray_knight|carries_goods(3),0,fac_commoners,soldier_personality,[]),
  ("messenger_party","Messenger",icon_gray_knight|pf_show_faction,0,fac_commoners,merchant_personality,[]),
  ("raider_party","Raiders",icon_gray_knight|carries_goods(16)|pf_quest_party,0,fac_commoners,bandit_personality,[]),
  ("raider_captives","Raider Captives",0,0,fac_commoners,0,[(trp_peasant_woman,6,30,pmf_is_prisoner)]),
  ("kingdom_caravan_party","Caravan",icon_mule|carries_goods(25)|pf_show_faction,0,fac_commoners,merchant_personality,[(trp_caravan_master,1,1),(trp_caravan_guard,12,40)]),
  ("prisoner_train_party","Prisoner Train",icon_gray_knight|carries_goods(5)|pf_show_faction,0,fac_commoners,merchant_personality,[]),
  ("default_prisoners","Default Prisoners",0,0,fac_commoners,0,[(trp_bandit,5,10,pmf_is_prisoner)]),

  ("routed_warriors","Routed Enemies",icon_vaegir_knight,0,fac_commoners,soldier_personality,[]),


# Caravans
  ("center_reinforcements","Reinforcements",icon_axeman|carries_goods(16),0,fac_commoners,soldier_personality,[(trp_townsman,5,30),(trp_watchman,4,20)]),  

  ("kingdom_hero_party","War Party",icon_flagbearer_a|pf_show_faction|pf_default_behavior,0,fac_commoners,soldier_personality,[]),
  
# Reinforcements
  # each faction includes three party templates. One is less-modernised, one is med-modernised and one is high-modernised
  # less-modernised templates are generally includes 7-14 troops in total, 
  # med-modernised templates are generally includes 5-10 troops in total, 
  # high-modernised templates are generally includes 3-5 troops in total

  ("kingdom_1_reinforcements_a", "{!}kingdom_1_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_swadian_recruit,5,10),(trp_swadian_militia,2,4)]),
  ("kingdom_1_reinforcements_b", "{!}kingdom_1_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_swadian_footman,3,6),(trp_swadian_skirmisher,2,4)]),
  ("kingdom_1_reinforcements_c", "{!}kingdom_1_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_swadian_man_at_arms,2,4),(trp_swadian_crossbowman,1,2)]), #Swadians are a bit less-powered thats why they have a bit more troops in their modernised party template (3-6, others 3-5)

  ("kingdom_2_reinforcements_a", "{!}kingdom_2_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_vaegir_recruit,5,10),(trp_vaegir_footman,2,4)]),
  ("kingdom_2_reinforcements_b", "{!}kingdom_2_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_vaegir_veteran,2,4),(trp_vaegir_skirmisher,2,4),(trp_vaegir_footman,1,2)]),
  ("kingdom_2_reinforcements_c", "{!}kingdom_2_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_vaegir_horseman,2,3),(trp_vaegir_infantry,1,2)]),

  ("kingdom_3_reinforcements_a", "{!}kingdom_3_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_khergit_tribesman,3,5),(trp_khergit_skirmisher,4,9)]), #Khergits are a bit less-powered thats why they have a bit more 2nd upgraded(trp_khergit_skirmisher) than non-upgraded one(trp_khergit_tribesman).
  ("kingdom_3_reinforcements_b", "{!}kingdom_3_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_khergit_horseman,2,4),(trp_khergit_horse_archer,2,4),(trp_khergit_skirmisher,1,2)]),
  ("kingdom_3_reinforcements_c", "{!}kingdom_3_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_khergit_horseman,2,4),(trp_khergit_veteran_horse_archer,2,3)]), #Khergits are a bit less-powered thats why they have a bit more troops in their modernised party template (4-7, others 3-5)

  ("kingdom_4_reinforcements_a", "{!}kingdom_4_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_nord_footman,5,10),(trp_nord_recruit,2,4)]),
  ("kingdom_4_reinforcements_b", "{!}kingdom_4_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_nord_huntsman,2,5),(trp_nord_archer,2,3),(trp_nord_footman,1,2)]),
  ("kingdom_4_reinforcements_c", "{!}kingdom_4_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_nord_warrior,3,5)]),

  ("kingdom_5_reinforcements_a", "{!}kingdom_5_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_rhodok_tribesman,5,10),(trp_rhodok_spearman,2,4)]),
  ("kingdom_5_reinforcements_b", "{!}kingdom_5_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_rhodok_crossbowman,3,6),(trp_rhodok_trained_crossbowman,2,4)]),
  ("kingdom_5_reinforcements_c", "{!}kingdom_5_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_rhodok_veteran_spearman,2,3),(trp_rhodok_veteran_crossbowman,1,2)]), 

  ("kingdom_6_reinforcements_a", "{!}kingdom_6_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_sarranid_recruit,5,10),(trp_sarranid_footman,2,4)]),
  ("kingdom_6_reinforcements_b", "{!}kingdom_6_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_sarranid_skirmisher,2,4),(trp_sarranid_veteran_footman,2,3),(trp_sarranid_footman,1,3)]),
  ("kingdom_6_reinforcements_c", "{!}kingdom_6_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_sarranid_horseman,3,5)]),

##  ("kingdom_1_reinforcements_a", "kingdom_1_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_swadian_footman,3,7),(trp_swadian_skirmisher,5,10),(trp_swadian_militia,11,26)]),
##  ("kingdom_1_reinforcements_b", "kingdom_1_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_swadian_man_at_arms,5,10),(trp_swadian_infantry,5,10),(trp_swadian_crossbowman,3,8)]),
##  ("kingdom_1_reinforcements_c", "kingdom_1_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_swadian_knight,2,6),(trp_swadian_sergeant,2,5),(trp_swadian_sharpshooter,2,5)]),
##
##  ("kingdom_2_reinforcements_a", "kingdom_2_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_vaegir_veteran,3,7),(trp_vaegir_skirmisher,5,10),(trp_vaegir_footman,11,26)]),
##  ("kingdom_2_reinforcements_b", "kingdom_2_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_vaegir_horseman,4,9),(trp_vaegir_infantry,5,10),(trp_vaegir_archer,3,8)]),
##  ("kingdom_2_reinforcements_c", "kingdom_2_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_vaegir_knight,3,7),(trp_vaegir_guard,2,5),(trp_vaegir_marksman,2,5)]),
##
##  ("kingdom_3_reinforcements_a", "kingdom_3_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_khergit_horseman,3,7),(trp_khergit_skirmisher,5,10),(trp_khergit_tribesman,11,26)]),
##  ("kingdom_3_reinforcements_b", "kingdom_3_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_khergit_veteran_horse_archer,4,9),(trp_khergit_horse_archer,5,10),(trp_khergit_horseman,3,8)]),
##  ("kingdom_3_reinforcements_c", "kingdom_3_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_khergit_lancer,3,7),(trp_khergit_veteran_horse_archer,2,5),(trp_khergit_horse_archer,2,5)]),
##
##  ("kingdom_4_reinforcements_a", "kingdom_4_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_nord_trained_footman,3,7),(trp_nord_footman,5,10),(trp_nord_recruit,11,26)]),
##  ("kingdom_4_reinforcements_b", "kingdom_4_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_nord_veteran,4,9),(trp_nord_warrior,5,10),(trp_nord_footman,3,8)]),
##  ("kingdom_4_reinforcements_c", "kingdom_4_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_nord_champion,1,3),(trp_nord_veteran,2,5),(trp_nord_warrior,2,5)]),
##
##  ("kingdom_5_reinforcements_a", "kingdom_5_reinforcements_a", 0, 0, fac_commoners, 0, [(trp_rhodok_spearman,3,7),(trp_rhodok_crossbowman,5,10),(trp_rhodok_tribesman,11,26)]),
##  ("kingdom_5_reinforcements_b", "kingdom_5_reinforcements_b", 0, 0, fac_commoners, 0, [(trp_rhodok_trained_spearman,4,9),(trp_rhodok_spearman,5,10),(trp_rhodok_crossbowman,3,8)]),
##  ("kingdom_5_reinforcements_c", "kingdom_5_reinforcements_c", 0, 0, fac_commoners, 0, [(trp_rhodok_sergeant,3,7),(trp_rhodok_veteran_spearman,2,5),(trp_rhodok_veteran_crossbowman,2,5)]),



  ("steppe_bandit_lair" ,"Steppe Bandit Lair",icon_bandit_lair|carries_goods(2)|pf_is_static|pf_hide_defenders,0,fac_neutral,bandit_personality,[(trp_steppe_bandit,15,58)]),
  ("taiga_bandit_lair","Tundra Bandit Lair",icon_bandit_lair|carries_goods(2)|pf_is_static|pf_hide_defenders,0,fac_neutral,bandit_personality,[(trp_taiga_bandit,15,58)]),
  ("desert_bandit_lair" ,"Desert Bandit Lair",icon_bandit_lair|carries_goods(2)|pf_is_static|pf_hide_defenders,0,fac_neutral,bandit_personality,[(trp_desert_bandit,15,58)]),
  ("forest_bandit_lair" ,"Forest Bandit Camp",icon_bandit_lair|carries_goods(2)|pf_is_static|pf_hide_defenders,0,fac_neutral,bandit_personality,[(trp_forest_bandit,15,58)]),
  ("mountain_bandit_lair" ,"Mountain Bandit Hideout",icon_bandit_lair|carries_goods(2)|pf_is_static|pf_hide_defenders,0,fac_neutral,bandit_personality,[(trp_mountain_bandit,15,58)]),
  ("sea_raider_lair","Sea Raider Landing",icon_bandit_lair|carries_goods(2)|pf_is_static|pf_hide_defenders,0,fac_neutral,bandit_personality,[(trp_sea_raider,15,50)]),
  ("looter_lair","Kidnappers' Hideout",icon_bandit_lair|carries_goods(2)|pf_is_static|pf_hide_defenders,0,fac_neutral,bandit_personality,[(trp_looter,15,25)]),
  
  ("bandit_lair_templates_end","{!}bandit_lair_templates_end",icon_axeman|carries_goods(2)|pf_is_static,0,fac_outlaws,bandit_personality,[(trp_sea_raider,15,50)]),

  ("leaded_looters","Band of robbers",icon_axeman|carries_goods(8)|pf_quest_party,0,fac_neutral,bandit_personality,[(trp_looter_leader,1,1),(trp_looter,3,3)]),
]



p_main_party = 0
p_temp_party = 1
p_camp_bandits = 2
p_temp_party_2 = 3
p_temp_casualties = 4
p_temp_casualties_2 = 5
p_temp_casualties_3 = 6
p_temp_wounded = 7
p_temp_killed = 8
p_main_party_backup = 9
p_encountered_party_backup = 10
p_collective_friends_backup = 11
p_player_casualties = 12
p_enemy_casualties = 13
p_ally_casualties = 14
p_collective_enemy = 15
p_collective_ally = 16
p_collective_friends = 17
p_total_enemy_casualties = 18
p_routed_enemies = 19
p_zendar = 20
p_town_1 = 21
p_town_2 = 22
p_town_3 = 23
p_town_4 = 24
p_town_5 = 25
p_town_6 = 26
p_town_7 = 27
p_town_8 = 28
p_town_9 = 29
p_town_10 = 30
p_town_11 = 31
p_town_12 = 32
p_town_13 = 33
p_town_14 = 34
p_town_15 = 35
p_town_16 = 36
p_town_17 = 37
p_town_18 = 38
p_town_19 = 39
p_town_20 = 40
p_town_21 = 41
p_town_22 = 42
p_castle_1 = 43
p_castle_2 = 44
p_castle_3 = 45
p_castle_4 = 46
p_castle_5 = 47
p_castle_6 = 48
p_castle_7 = 49
p_castle_8 = 50
p_castle_9 = 51
p_castle_10 = 52
p_castle_11 = 53
p_castle_12 = 54
p_castle_13 = 55
p_castle_14 = 56
p_castle_15 = 57
p_castle_16 = 58
p_castle_17 = 59
p_castle_18 = 60
p_castle_19 = 61
p_castle_20 = 62
p_castle_21 = 63
p_castle_22 = 64
p_castle_23 = 65
p_castle_24 = 66
p_castle_25 = 67
p_castle_26 = 68
p_castle_27 = 69
p_castle_28 = 70
p_castle_29 = 71
p_castle_30 = 72
p_castle_31 = 73
p_castle_32 = 74
p_castle_33 = 75
p_castle_34 = 76
p_castle_35 = 77
p_castle_36 = 78
p_castle_37 = 79
p_castle_38 = 80
p_castle_39 = 81
p_castle_40 = 82
p_castle_41 = 83
p_castle_42 = 84
p_castle_43 = 85
p_castle_44 = 86
p_castle_45 = 87
p_castle_46 = 88
p_castle_47 = 89
p_castle_48 = 90
p_village_1 = 91
p_village_2 = 92
p_village_3 = 93
p_village_4 = 94
p_village_5 = 95
p_village_6 = 96
p_village_7 = 97
p_village_8 = 98
p_village_9 = 99
p_village_10 = 100
p_village_11 = 101
p_village_12 = 102
p_village_13 = 103
p_village_14 = 104
p_village_15 = 105
p_village_16 = 106
p_village_17 = 107
p_village_18 = 108
p_village_19 = 109
p_village_20 = 110
p_village_21 = 111
p_village_22 = 112
p_village_23 = 113
p_village_24 = 114
p_village_25 = 115
p_village_26 = 116
p_village_27 = 117
p_village_28 = 118
p_village_29 = 119
p_village_30 = 120
p_village_31 = 121
p_village_32 = 122
p_village_33 = 123
p_village_34 = 124
p_village_35 = 125
p_village_36 = 126
p_village_37 = 127
p_village_38 = 128
p_village_39 = 129
p_village_40 = 130
p_village_41 = 131
p_village_42 = 132
p_village_43 = 133
p_village_44 = 134
p_village_45 = 135
p_village_46 = 136
p_village_47 = 137
p_village_48 = 138
p_village_49 = 139
p_village_50 = 140
p_village_51 = 141
p_village_52 = 142
p_village_53 = 143
p_village_54 = 144
p_village_55 = 145
p_village_56 = 146
p_village_57 = 147
p_village_58 = 148
p_village_59 = 149
p_village_60 = 150
p_village_61 = 151
p_village_62 = 152
p_village_63 = 153
p_village_64 = 154
p_village_65 = 155
p_village_66 = 156
p_village_67 = 157
p_village_68 = 158
p_village_69 = 159
p_village_70 = 160
p_village_71 = 161
p_village_72 = 162
p_village_73 = 163
p_village_74 = 164
p_village_75 = 165
p_village_76 = 166
p_village_77 = 167
p_village_78 = 168
p_village_79 = 169
p_village_80 = 170
p_village_81 = 171
p_village_82 = 172
p_village_83 = 173
p_village_84 = 174
p_village_85 = 175
p_village_86 = 176
p_village_87 = 177
p_village_88 = 178
p_village_89 = 179
p_village_90 = 180
p_village_91 = 181
p_village_92 = 182
p_village_93 = 183
p_village_94 = 184
p_village_95 = 185
p_village_96 = 186
p_village_97 = 187
p_village_98 = 188
p_village_99 = 189
p_village_100 = 190
p_village_101 = 191
p_village_102 = 192
p_village_103 = 193
p_village_104 = 194
p_village_105 = 195
p_village_106 = 196
p_village_107 = 197
p_village_108 = 198
p_village_109 = 199
p_village_110 = 200
p_salt_mine = 201
p_four_ways_inn = 202
p_test_scene = 203
p_battlefields = 204
p_dhorak_keep = 205
p_training_ground = 206
p_training_ground_1 = 207
p_training_ground_2 = 208
p_training_ground_3 = 209
p_training_ground_4 = 210
p_training_ground_5 = 211
p_bridge_1 = 212
p_bridge_2 = 213
p_bridge_3 = 214
p_bridge_4 = 215
p_bridge_5 = 216
p_bridge_6 = 217
p_bridge_7 = 218
p_bridge_8 = 219
p_bridge_9 = 220
p_bridge_10 = 221
p_bridge_11 = 222
p_bridge_12 = 223
p_bridge_13 = 224
p_bridge_14 = 225
p_looter_spawn_point = 226
p_steppe_bandit_spawn_point = 227
p_taiga_bandit_spawn_point = 228
p_forest_bandit_spawn_point = 229
p_mountain_bandit_spawn_point = 230
p_sea_raider_spawn_point_1 = 231
p_sea_raider_spawn_point_2 = 232
p_desert_bandit_spawn_point = 233
p_spawn_points_end = 234
p_reserved_1 = 235
p_reserved_2 = 236
p_reserved_3 = 237
p_reserved_4 = 238
p_reserved_5 = 239



icon_player = 0
icon_player_horseman = 1
icon_gray_knight = 2
icon_vaegir_knight = 3
icon_flagbearer_a = 4
icon_flagbearer_b = 5
icon_peasant = 6
icon_khergit = 7
icon_khergit_horseman_b = 8
icon_axeman = 9
icon_woman = 10
icon_woman_b = 11
icon_town = 12
icon_town_steppe = 13
icon_town_desert = 14
icon_village_a = 15
icon_village_b = 16
icon_village_c = 17
icon_village_burnt_a = 18
icon_village_deserted_a = 19
icon_village_burnt_b = 20
icon_village_deserted_b = 21
icon_village_burnt_c = 22
icon_village_deserted_c = 23
icon_village_snow_a = 24
icon_village_snow_burnt_a = 25
icon_village_snow_deserted_a = 26
icon_camp = 27
icon_ship = 28
icon_ship_on_land = 29
icon_castle_a = 30
icon_castle_b = 31
icon_castle_c = 32
icon_castle_d = 33
icon_town_snow = 34
icon_castle_snow_a = 35
icon_castle_snow_b = 36
icon_mule = 37
icon_cattle = 38
icon_training_ground = 39
icon_bridge_a = 40
icon_bridge_b = 41
icon_bridge_snow_a = 42
icon_custom_banner_01 = 43
icon_custom_banner_02 = 44
icon_custom_banner_03 = 45
icon_banner_01 = 46
icon_banner_02 = 47
icon_banner_03 = 48
icon_banner_04 = 49
icon_banner_05 = 50
icon_banner_06 = 51
icon_banner_07 = 52
icon_banner_08 = 53
icon_banner_09 = 54
icon_banner_10 = 55
icon_banner_11 = 56
icon_banner_12 = 57
icon_banner_13 = 58
icon_banner_14 = 59
icon_banner_15 = 60
icon_banner_16 = 61
icon_banner_17 = 62
icon_banner_18 = 63
icon_banner_19 = 64
icon_banner_20 = 65
icon_banner_21 = 66
icon_banner_22 = 67
icon_banner_23 = 68
icon_banner_24 = 69
icon_banner_25 = 70
icon_banner_26 = 71
icon_banner_27 = 72
icon_banner_28 = 73
icon_banner_29 = 74
icon_banner_30 = 75
icon_banner_31 = 76
icon_banner_32 = 77
icon_banner_33 = 78
icon_banner_34 = 79
icon_banner_35 = 80
icon_banner_36 = 81
icon_banner_37 = 82
icon_banner_38 = 83
icon_banner_39 = 84
icon_banner_40 = 85
icon_banner_41 = 86
icon_banner_42 = 87
icon_banner_43 = 88
icon_banner_44 = 89
icon_banner_45 = 90
icon_banner_46 = 91
icon_banner_47 = 92
icon_banner_48 = 93
icon_banner_49 = 94
icon_banner_50 = 95
icon_banner_51 = 96
icon_banner_52 = 97
icon_banner_53 = 98
icon_banner_54 = 99
icon_banner_55 = 100
icon_banner_56 = 101
icon_banner_57 = 102
icon_banner_58 = 103
icon_banner_59 = 104
icon_banner_60 = 105
icon_banner_61 = 106
icon_banner_62 = 107
icon_banner_63 = 108
icon_banner_64 = 109
icon_banner_65 = 110
icon_banner_66 = 111
icon_banner_67 = 112
icon_banner_68 = 113
icon_banner_69 = 114
icon_banner_70 = 115
icon_banner_71 = 116
icon_banner_72 = 117
icon_banner_73 = 118
icon_banner_74 = 119
icon_banner_75 = 120
icon_banner_76 = 121
icon_banner_77 = 122
icon_banner_78 = 123
icon_banner_79 = 124
icon_banner_80 = 125
icon_banner_81 = 126
icon_banner_82 = 127
icon_banner_83 = 128
icon_banner_84 = 129
icon_banner_85 = 130
icon_banner_86 = 131
icon_banner_87 = 132
icon_banner_88 = 133
icon_banner_89 = 134
icon_banner_90 = 135
icon_banner_91 = 136
icon_banner_92 = 137
icon_banner_93 = 138
icon_banner_94 = 139
icon_banner_95 = 140
icon_banner_96 = 141
icon_banner_97 = 142
icon_banner_98 = 143
icon_banner_99 = 144
icon_banner_100 = 145
icon_banner_101 = 146
icon_banner_102 = 147
icon_banner_103 = 148
icon_banner_104 = 149
icon_banner_105 = 150
icon_banner_106 = 151
icon_banner_107 = 152
icon_banner_108 = 153
icon_banner_109 = 154
icon_banner_110 = 155
icon_banner_111 = 156
icon_banner_112 = 157
icon_banner_113 = 158
icon_banner_114 = 159
icon_banner_115 = 160
icon_banner_116 = 161
icon_banner_117 = 162
icon_banner_118 = 163
icon_banner_119 = 164
icon_banner_120 = 165
icon_banner_121 = 166
icon_banner_122 = 167
icon_banner_123 = 168
icon_banner_124 = 169
icon_banner_125 = 170
icon_banner_126 = 171
icon_banner_127 = 172
icon_banner_128 = 173
icon_banner_129 = 174
icon_banner_130 = 175
icon_banner_131 = 176
icon_banner_132 = 177
icon_banner_133 = 178
icon_banner_134 = 179
icon_banner_135 = 180
icon_map_flag_kingdom_a = 181
icon_map_flag_kingdom_b = 182
icon_map_flag_kingdom_c = 183
icon_map_flag_kingdom_d = 184
icon_map_flag_kingdom_e = 185
icon_map_flag_kingdom_f = 186
icon_banner_136 = 187
icon_bandit_lair = 188



mesh_pic_bandits = 0
mesh_pic_mb_warrior_1 = 1
mesh_pic_messenger = 2
mesh_pic_prisoner_man = 3
mesh_pic_prisoner_fem = 4
mesh_pic_prisoner_wilderness = 5
mesh_pic_siege_sighted = 6
mesh_pic_siege_sighted_fem = 7
mesh_pic_camp = 8
mesh_pic_payment = 9
mesh_pic_escape_1 = 10
mesh_pic_escape_1_fem = 11
mesh_pic_victory = 12
mesh_pic_defeat = 13
mesh_pic_wounded = 14
mesh_pic_wounded_fem = 15
mesh_pic_steppe_bandits = 16
mesh_pic_mountain_bandits = 17
mesh_pic_sea_raiders = 18
mesh_pic_deserters = 19
mesh_pic_forest_bandits = 20
mesh_pic_cattle = 21
mesh_pic_looted_village = 22
mesh_pic_village_p = 23
mesh_pic_village_s = 24
mesh_pic_village_w = 25
mesh_pic_recruits = 26
mesh_pic_arms_swadian = 27
mesh_pic_arms_vaegir = 28
mesh_pic_arms_khergit = 29
mesh_pic_arms_nord = 30
mesh_pic_arms_rhodok = 31
mesh_pic_sarranid_arms = 32
mesh_pic_castle1 = 33
mesh_pic_castledes = 34
mesh_pic_castlesnow = 35
mesh_pic_charge = 36
mesh_pic_khergit = 37
mesh_pic_nord = 38
mesh_pic_rhodock = 39
mesh_pic_sally_out = 40
mesh_pic_siege_attack = 41
mesh_pic_swad = 42
mesh_pic_town1 = 43
mesh_pic_towndes = 44
mesh_pic_townriot = 45
mesh_pic_townsnow = 46
mesh_pic_vaegir = 47
mesh_pic_villageriot = 48
mesh_pic_sarranid_encounter = 49
mesh_mp_score_a = 50
mesh_mp_score_b = 51
mesh_portrait_blend_out = 52
mesh_load_window = 53
mesh_checkbox_off = 54
mesh_checkbox_on = 55
mesh_white_plane = 56
mesh_white_dot = 57
mesh_player_dot = 58
mesh_flag_infantry = 59
mesh_flag_archers = 60
mesh_flag_cavalry = 61
mesh_inv_slot = 62
mesh_mp_ingame_menu = 63
mesh_mp_inventory_left = 64
mesh_mp_inventory_right = 65
mesh_mp_inventory_choose = 66
mesh_mp_inventory_slot_glove = 67
mesh_mp_inventory_slot_horse = 68
mesh_mp_inventory_slot_armor = 69
mesh_mp_inventory_slot_helmet = 70
mesh_mp_inventory_slot_boot = 71
mesh_mp_inventory_slot_empty = 72
mesh_mp_inventory_slot_equip = 73
mesh_mp_inventory_left_arrow = 74
mesh_mp_inventory_right_arrow = 75
mesh_mp_ui_host_main = 76
mesh_mp_ui_host_maps_1 = 77
mesh_mp_ui_host_maps_2 = 78
mesh_mp_ui_host_maps_3 = 79
mesh_mp_ui_host_maps_4 = 80
mesh_mp_ui_host_maps_5 = 81
mesh_mp_ui_host_maps_6 = 82
mesh_mp_ui_host_maps_7 = 83
mesh_mp_ui_host_maps_8 = 84
mesh_mp_ui_host_maps_9 = 85
mesh_mp_ui_host_maps_10 = 86
mesh_mp_ui_host_maps_11 = 87
mesh_mp_ui_host_maps_12 = 88
mesh_mp_ui_host_maps_13 = 89
mesh_mp_ui_host_maps_randomp = 90
mesh_mp_ui_host_maps_randoms = 91
mesh_mp_ui_command_panel = 92
mesh_mp_ui_command_border_l = 93
mesh_mp_ui_command_border_r = 94
mesh_mp_ui_welcome_panel = 95
mesh_flag_project_sw = 96
mesh_flag_project_vg = 97
mesh_flag_project_kh = 98
mesh_flag_project_nd = 99
mesh_flag_project_rh = 100
mesh_flag_project_sr = 101
mesh_flag_projects_end = 102
mesh_flag_project_sw_miss = 103
mesh_flag_project_vg_miss = 104
mesh_flag_project_kh_miss = 105
mesh_flag_project_nd_miss = 106
mesh_flag_project_rh_miss = 107
mesh_flag_project_sr_miss = 108
mesh_flag_project_misses_end = 109
mesh_color_picker = 110
mesh_custom_map_banner_01 = 111
mesh_custom_map_banner_02 = 112
mesh_custom_map_banner_03 = 113
mesh_custom_banner_01 = 114
mesh_custom_banner_02 = 115
mesh_custom_banner_bg = 116
mesh_custom_banner_fg01 = 117
mesh_custom_banner_fg02 = 118
mesh_custom_banner_fg03 = 119
mesh_custom_banner_fg04 = 120
mesh_custom_banner_fg05 = 121
mesh_custom_banner_fg06 = 122
mesh_custom_banner_fg07 = 123
mesh_custom_banner_fg08 = 124
mesh_custom_banner_fg09 = 125
mesh_custom_banner_fg10 = 126
mesh_custom_banner_fg11 = 127
mesh_custom_banner_fg12 = 128
mesh_custom_banner_fg13 = 129
mesh_custom_banner_fg14 = 130
mesh_custom_banner_fg15 = 131
mesh_custom_banner_fg16 = 132
mesh_custom_banner_fg17 = 133
mesh_custom_banner_fg18 = 134
mesh_custom_banner_fg19 = 135
mesh_custom_banner_fg20 = 136
mesh_custom_banner_fg21 = 137
mesh_custom_banner_fg22 = 138
mesh_custom_banner_fg23 = 139
mesh_custom_banner_charge_01 = 140
mesh_custom_banner_charge_02 = 141
mesh_custom_banner_charge_03 = 142
mesh_custom_banner_charge_04 = 143
mesh_custom_banner_charge_05 = 144
mesh_custom_banner_charge_06 = 145
mesh_custom_banner_charge_07 = 146
mesh_custom_banner_charge_08 = 147
mesh_custom_banner_charge_09 = 148
mesh_custom_banner_charge_10 = 149
mesh_custom_banner_charge_11 = 150
mesh_custom_banner_charge_12 = 151
mesh_custom_banner_charge_13 = 152
mesh_custom_banner_charge_14 = 153
mesh_custom_banner_charge_15 = 154
mesh_custom_banner_charge_16 = 155
mesh_custom_banner_charge_17 = 156
mesh_custom_banner_charge_18 = 157
mesh_custom_banner_charge_19 = 158
mesh_custom_banner_charge_20 = 159
mesh_custom_banner_charge_21 = 160
mesh_custom_banner_charge_22 = 161
mesh_custom_banner_charge_23 = 162
mesh_custom_banner_charge_24 = 163
mesh_custom_banner_charge_25 = 164
mesh_custom_banner_charge_26 = 165
mesh_custom_banner_charge_27 = 166
mesh_custom_banner_charge_28 = 167
mesh_custom_banner_charge_29 = 168
mesh_custom_banner_charge_30 = 169
mesh_custom_banner_charge_31 = 170
mesh_custom_banner_charge_32 = 171
mesh_custom_banner_charge_33 = 172
mesh_custom_banner_charge_34 = 173
mesh_custom_banner_charge_35 = 174
mesh_custom_banner_charge_36 = 175
mesh_custom_banner_charge_37 = 176
mesh_custom_banner_charge_38 = 177
mesh_custom_banner_charge_39 = 178
mesh_custom_banner_charge_40 = 179
mesh_custom_banner_charge_41 = 180
mesh_custom_banner_charge_42 = 181
mesh_custom_banner_charge_43 = 182
mesh_custom_banner_charge_44 = 183
mesh_custom_banner_charge_45 = 184
mesh_custom_banner_charge_46 = 185
mesh_tableau_mesh_custom_banner = 186
mesh_tableau_mesh_custom_banner_square = 187
mesh_tableau_mesh_custom_banner_tall = 188
mesh_tableau_mesh_custom_banner_short = 189
mesh_tableau_mesh_shield_round_1 = 190
mesh_tableau_mesh_shield_round_2 = 191
mesh_tableau_mesh_shield_round_3 = 192
mesh_tableau_mesh_shield_round_4 = 193
mesh_tableau_mesh_shield_round_5 = 194
mesh_tableau_mesh_shield_small_round_1 = 195
mesh_tableau_mesh_shield_small_round_2 = 196
mesh_tableau_mesh_shield_small_round_3 = 197
mesh_tableau_mesh_shield_kite_1 = 198
mesh_tableau_mesh_shield_kite_2 = 199
mesh_tableau_mesh_shield_kite_3 = 200
mesh_tableau_mesh_shield_kite_4 = 201
mesh_tableau_mesh_shield_heater_1 = 202
mesh_tableau_mesh_shield_heater_2 = 203
mesh_tableau_mesh_shield_pavise_1 = 204
mesh_tableau_mesh_shield_pavise_2 = 205
mesh_heraldic_armor_bg = 206
mesh_tableau_mesh_heraldic_armor_a = 207
mesh_tableau_mesh_heraldic_armor_b = 208
mesh_tableau_mesh_heraldic_armor_c = 209
mesh_tableau_mesh_heraldic_armor_d = 210
mesh_outer_terrain_plain_1 = 211
mesh_banner_a01 = 212
mesh_banner_a02 = 213
mesh_banner_a03 = 214
mesh_banner_a04 = 215
mesh_banner_a05 = 216
mesh_banner_a06 = 217
mesh_banner_a07 = 218
mesh_banner_a08 = 219
mesh_banner_a09 = 220
mesh_banner_a10 = 221
mesh_banner_a11 = 222
mesh_banner_a12 = 223
mesh_banner_a13 = 224
mesh_banner_a14 = 225
mesh_banner_a15 = 226
mesh_banner_a16 = 227
mesh_banner_a17 = 228
mesh_banner_a18 = 229
mesh_banner_a19 = 230
mesh_banner_a20 = 231
mesh_banner_a21 = 232
mesh_banner_b01 = 233
mesh_banner_b02 = 234
mesh_banner_b03 = 235
mesh_banner_b04 = 236
mesh_banner_b05 = 237
mesh_banner_b06 = 238
mesh_banner_b07 = 239
mesh_banner_b08 = 240
mesh_banner_b09 = 241
mesh_banner_b10 = 242
mesh_banner_b11 = 243
mesh_banner_b12 = 244
mesh_banner_b13 = 245
mesh_banner_b14 = 246
mesh_banner_b15 = 247
mesh_banner_b16 = 248
mesh_banner_b17 = 249
mesh_banner_b18 = 250
mesh_banner_b19 = 251
mesh_banner_b20 = 252
mesh_banner_b21 = 253
mesh_banner_c01 = 254
mesh_banner_c02 = 255
mesh_banner_c03 = 256
mesh_banner_c04 = 257
mesh_banner_c05 = 258
mesh_banner_c06 = 259
mesh_banner_c07 = 260
mesh_banner_c08 = 261
mesh_banner_c09 = 262
mesh_banner_c10 = 263
mesh_banner_c11 = 264
mesh_banner_c12 = 265
mesh_banner_c13 = 266
mesh_banner_c14 = 267
mesh_banner_c15 = 268
mesh_banner_c16 = 269
mesh_banner_c17 = 270
mesh_banner_c18 = 271
mesh_banner_c19 = 272
mesh_banner_c20 = 273
mesh_banner_c21 = 274
mesh_banner_d01 = 275
mesh_banner_d02 = 276
mesh_banner_d03 = 277
mesh_banner_d04 = 278
mesh_banner_d05 = 279
mesh_banner_d06 = 280
mesh_banner_d07 = 281
mesh_banner_d08 = 282
mesh_banner_d09 = 283
mesh_banner_d10 = 284
mesh_banner_d11 = 285
mesh_banner_d12 = 286
mesh_banner_d13 = 287
mesh_banner_d14 = 288
mesh_banner_d15 = 289
mesh_banner_d16 = 290
mesh_banner_d17 = 291
mesh_banner_d18 = 292
mesh_banner_d19 = 293
mesh_banner_d20 = 294
mesh_banner_d21 = 295
mesh_banner_e01 = 296
mesh_banner_e02 = 297
mesh_banner_e03 = 298
mesh_banner_e04 = 299
mesh_banner_e05 = 300
mesh_banner_e06 = 301
mesh_banner_e07 = 302
mesh_banner_e08 = 303
mesh_banner_e09 = 304
mesh_banner_e10 = 305
mesh_banner_e11 = 306
mesh_banner_e12 = 307
mesh_banner_e13 = 308
mesh_banner_e14 = 309
mesh_banner_e15 = 310
mesh_banner_e16 = 311
mesh_banner_e17 = 312
mesh_banner_e18 = 313
mesh_banner_e19 = 314
mesh_banner_e20 = 315
mesh_banner_e21 = 316
mesh_banner_f01 = 317
mesh_banner_f02 = 318
mesh_banner_f03 = 319
mesh_banner_f04 = 320
mesh_banner_f05 = 321
mesh_banner_f06 = 322
mesh_banner_f07 = 323
mesh_banner_f08 = 324
mesh_banner_f09 = 325
mesh_banner_f10 = 326
mesh_banner_f11 = 327
mesh_banner_f12 = 328
mesh_banner_f13 = 329
mesh_banner_f14 = 330
mesh_banner_f15 = 331
mesh_banner_f16 = 332
mesh_banner_f17 = 333
mesh_banner_f18 = 334
mesh_banner_f19 = 335
mesh_banner_f20 = 336
mesh_banner_g01 = 337
mesh_banner_g02 = 338
mesh_banner_g03 = 339
mesh_banner_g04 = 340
mesh_banner_g05 = 341
mesh_banner_g06 = 342
mesh_banner_g07 = 343
mesh_banner_g08 = 344
mesh_banner_g09 = 345
mesh_banner_g10 = 346
mesh_banner_kingdom_a = 347
mesh_banner_kingdom_b = 348
mesh_banner_kingdom_c = 349
mesh_banner_kingdom_d = 350
mesh_banner_kingdom_e = 351
mesh_banner_kingdom_f = 352
mesh_banner_f21 = 353
mesh_arms_a01 = 354
mesh_arms_a02 = 355
mesh_arms_a03 = 356
mesh_arms_a04 = 357
mesh_arms_a05 = 358
mesh_arms_a06 = 359
mesh_arms_a07 = 360
mesh_arms_a08 = 361
mesh_arms_a09 = 362
mesh_arms_a10 = 363
mesh_arms_a11 = 364
mesh_arms_a12 = 365
mesh_arms_a13 = 366
mesh_arms_a14 = 367
mesh_arms_a15 = 368
mesh_arms_a16 = 369
mesh_arms_a17 = 370
mesh_arms_a18 = 371
mesh_arms_a19 = 372
mesh_arms_a20 = 373
mesh_arms_a21 = 374
mesh_arms_b01 = 375
mesh_arms_b02 = 376
mesh_arms_b03 = 377
mesh_arms_b04 = 378
mesh_arms_b05 = 379
mesh_arms_b06 = 380
mesh_arms_b07 = 381
mesh_arms_b08 = 382
mesh_arms_b09 = 383
mesh_arms_b10 = 384
mesh_arms_b11 = 385
mesh_arms_b12 = 386
mesh_arms_b13 = 387
mesh_arms_b14 = 388
mesh_arms_b15 = 389
mesh_arms_b16 = 390
mesh_arms_b17 = 391
mesh_arms_b18 = 392
mesh_arms_b19 = 393
mesh_arms_b20 = 394
mesh_arms_b21 = 395
mesh_arms_c01 = 396
mesh_arms_c02 = 397
mesh_arms_c03 = 398
mesh_arms_c04 = 399
mesh_arms_c05 = 400
mesh_arms_c06 = 401
mesh_arms_c07 = 402
mesh_arms_c08 = 403
mesh_arms_c09 = 404
mesh_arms_c10 = 405
mesh_arms_c11 = 406
mesh_arms_c12 = 407
mesh_arms_c13 = 408
mesh_arms_c14 = 409
mesh_arms_c15 = 410
mesh_arms_c16 = 411
mesh_arms_c17 = 412
mesh_arms_c18 = 413
mesh_arms_c19 = 414
mesh_arms_c20 = 415
mesh_arms_c21 = 416
mesh_arms_d01 = 417
mesh_arms_d02 = 418
mesh_arms_d03 = 419
mesh_arms_d04 = 420
mesh_arms_d05 = 421
mesh_arms_d06 = 422
mesh_arms_d07 = 423
mesh_arms_d08 = 424
mesh_arms_d09 = 425
mesh_arms_d10 = 426
mesh_arms_d11 = 427
mesh_arms_d12 = 428
mesh_arms_d13 = 429
mesh_arms_d14 = 430
mesh_arms_d15 = 431
mesh_arms_d16 = 432
mesh_arms_d17 = 433
mesh_arms_d18 = 434
mesh_arms_d19 = 435
mesh_arms_d20 = 436
mesh_arms_d21 = 437
mesh_arms_e01 = 438
mesh_arms_e02 = 439
mesh_arms_e03 = 440
mesh_arms_e04 = 441
mesh_arms_e05 = 442
mesh_arms_e06 = 443
mesh_arms_e07 = 444
mesh_arms_e08 = 445
mesh_arms_e09 = 446
mesh_arms_e10 = 447
mesh_arms_e11 = 448
mesh_arms_e12 = 449
mesh_arms_e13 = 450
mesh_arms_e14 = 451
mesh_arms_e15 = 452
mesh_arms_e16 = 453
mesh_arms_e17 = 454
mesh_arms_e18 = 455
mesh_arms_e19 = 456
mesh_arms_e20 = 457
mesh_arms_e21 = 458
mesh_arms_f01 = 459
mesh_arms_f02 = 460
mesh_arms_f03 = 461
mesh_arms_f04 = 462
mesh_arms_f05 = 463
mesh_arms_f06 = 464
mesh_arms_f07 = 465
mesh_arms_f08 = 466
mesh_arms_f09 = 467
mesh_arms_f10 = 468
mesh_arms_f11 = 469
mesh_arms_f12 = 470
mesh_arms_f13 = 471
mesh_arms_f14 = 472
mesh_arms_f15 = 473
mesh_arms_f16 = 474
mesh_arms_f17 = 475
mesh_arms_f18 = 476
mesh_arms_f19 = 477
mesh_arms_f20 = 478
mesh_arms_g01 = 479
mesh_arms_g02 = 480
mesh_arms_g03 = 481
mesh_arms_g04 = 482
mesh_arms_g05 = 483
mesh_arms_g06 = 484
mesh_arms_g07 = 485
mesh_arms_g08 = 486
mesh_arms_g09 = 487
mesh_arms_g10 = 488
mesh_arms_kingdom_a = 489
mesh_arms_kingdom_b = 490
mesh_arms_kingdom_c = 491
mesh_arms_kingdom_d = 492
mesh_arms_kingdom_e = 493
mesh_arms_kingdom_f = 494
mesh_arms_f21 = 495
mesh_banners_default_a = 496
mesh_banners_default_b = 497
mesh_banners_default_c = 498
mesh_banners_default_d = 499
mesh_banners_default_e = 500
mesh_troop_label_banner = 501
mesh_ui_kingdom_shield_1 = 502
mesh_ui_kingdom_shield_2 = 503
mesh_ui_kingdom_shield_3 = 504
mesh_ui_kingdom_shield_4 = 505
mesh_ui_kingdom_shield_5 = 506
mesh_ui_kingdom_shield_6 = 507
mesh_mouse_arrow_down = 508
mesh_mouse_arrow_right = 509
mesh_mouse_arrow_left = 510
mesh_mouse_arrow_up = 511
mesh_mouse_arrow_plus = 512
mesh_mouse_left_click = 513
mesh_mouse_right_click = 514
mesh_status_ammo_ready = 515
mesh_main_menu_background = 516
mesh_loading_background = 517
mesh_ui_quick_battle_a = 518
mesh_white_bg_plane_a = 519
mesh_cb_ui_icon_infantry = 520
mesh_cb_ui_icon_archer = 521
mesh_cb_ui_icon_horseman = 522
mesh_cb_ui_main = 523
mesh_cb_ui_maps_scene_01 = 524
mesh_cb_ui_maps_scene_02 = 525
mesh_cb_ui_maps_scene_03 = 526
mesh_cb_ui_maps_scene_04 = 527
mesh_cb_ui_maps_scene_05 = 528
mesh_cb_ui_maps_scene_06 = 529
mesh_cb_ui_maps_scene_07 = 530
mesh_cb_ui_maps_scene_08 = 531
mesh_cb_ui_maps_scene_09 = 532
mesh_mp_ui_host_maps_14 = 533
mesh_mp_ui_host_maps_15 = 534
mesh_quit_adv = 535
mesh_quit_adv_b = 536
mesh_ui_kingdom_shield_7 = 537
mesh_flag_project_rb = 538
mesh_flag_project_rb_miss = 539
mesh_mp_ui_host_maps_16 = 540
mesh_mp_ui_host_maps_17 = 541
mesh_mp_ui_host_maps_18 = 542
mesh_mp_ui_host_maps_19 = 543
mesh_mp_ui_host_maps_20 = 544





import os

################################################
###
### banner图的输出
###
################################################
class BannerPrinter:
    def __init__(self):
        pass
    def print(self,filePath = "/smart_core/banner.txt",params={}):
        bannerFile = open(os.getcwd() + filePath)
        lines = bannerFile.readlines()
        for line in lines:
            print(self.translateLine(line,params),end="")
        print()
    def translateLine(self,line,params):
        for (key,val) in params.items():
            arg = "${"+key+"}"
            line = line.replace(arg,str(val))
        return line